==> kotlin-compiler-embeddable-0.12.1230-sources.jar: org/jetbrains/kotlin/cli/common/modules/ModuleBuilder.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.cli.common.modules

import java.util.ArrayList

public class ModuleBuilder(private val name: String, private val outputDir: String) : Module {
    private val sourceFiles = ArrayList<String>()
    private val classpathRoots = ArrayList<String>()
    private val javaSourceRoots = ArrayList<String>()
    private val annotationsRoots = ArrayList<String>()

    public fun addSourceFiles(pattern: String) {
        sourceFiles.add(pattern)
    }

    public fun addClasspathEntry(name: String) {
        classpathRoots.add(name)
    }

    public fun addAnnotationsPathEntry(name: String) {
        annotationsRoots.add(name)
    }

    public fun addJavaSourceRoot(name: String) {
        javaSourceRoots.add(name)
    }

    override fun getOutputDirectory(): String = outputDir
    override fun getJavaSourceRoots(): List<String> = javaSourceRoots
    override fun getSourceFiles(): List<String> = sourceFiles
    override fun getClasspathRoots(): List<String> = classpathRoots
    override fun getAnnotationsRoots(): List<String> = annotationsRoots
    override fun getModuleName(): String = name
}

==> kotlin-compiler-embeddable-0.13.1513-sources.jar: org/jetbrains/kotlin/cli/common/modules/ModuleBuilder.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.cli.common.modules

import org.jetbrains.kotlin.modules.Module
import java.util.*

public class ModuleBuilder(
        private val name: String,
        private val outputDir: String,
        private val type: String
) : Module {
    private val sourceFiles = ArrayList<String>()
    private val classpathRoots = ArrayList<String>()
    private val javaSourceRoots = ArrayList<String>()
    private val annotationsRoots = ArrayList<String>()

    public fun addSourceFiles(pattern: String) {
        sourceFiles.add(pattern)
    }

    public fun addClasspathEntry(name: String) {
        classpathRoots.add(name)
    }

    public fun addAnnotationsPathEntry(name: String) {
        annotationsRoots.add(name)
    }

    public fun addJavaSourceRoot(name: String) {
        javaSourceRoots.add(name)
    }

    override fun getOutputDirectory(): String = outputDir
    override fun getJavaSourceRoots(): List<String> = javaSourceRoots
    override fun getSourceFiles(): List<String> = sourceFiles
    override fun getClasspathRoots(): List<String> = classpathRoots
    override fun getAnnotationsRoots(): List<String> = annotationsRoots
    override fun getModuleName(): String = name
    override fun getModuleType(): String = type
}
